@@ -1,6 +1,12 @@
 """Plugin declaration for aristacv_sync."""
 
-__version__ = "1.0.6"
+try:
+    from importlib import metadata
+except ImportError:
+    # Python version < 3.8
+    import importlib_metadata as metadata
+
+__version__ = metadata.version(__name__)
 
 import os
 
@@ -21,11 +27,11 @@ class NautobotSSOTAristaCVConfig(PluginConfig):
     min_version = "1.0.0"
     max_version = "1.9999"
     default_settings = {
-        "cvp_host": os.getenv("CVP_HOST"),
-        "cvp_user": os.getenv("CVP_USER"),
-        "cvp_password": os.getenv("CVP_PASSWORD"),
-        "insecure": os.getenv("CVP_INSECURE") or False,
-        "cvp_token": os.getenv("CVP_TOKEN"),
+        "cvp_host": os.getenv("NAUTOBOT_ARISTACV_HOST"),
+        "cvp_user": os.getenv("NAUTOBOT_ARISTACV_USERNAME"),
+        "cvp_password": os.getenv("NAUTOBOT_ARISTACV_PASSWORD"),
+        "verify": os.getenv("NAUTOBOT_ARISTACVP_VERIFY"),
+        "cvp_token": os.getenv("NAUTOBOT_ARISTACV_TOKEN"),
     }
     caching_config = {}
 
